=======
PySIGEP
=======

.. image:: https://img.shields.io/travis/mstuttgart/pysigep/develop.svg?style=flat-square
    :target: https://travis-ci.org/mstuttgart/pysigep

.. image:: https://img.shields.io/coveralls/mstuttgart/pysigep/develop.svg?style=flat-square
    :target: https://coveralls.io/github/mstuttgart/pysigep?branch=develop

.. image:: https://landscape.io/github/mstuttgart/pysigep/develop/landscape.svg?style=flat-square
    :target: https://landscape.io/github/mstuttgart/pysigep/develop

.. image:: https://img.shields.io/pypi/v/pysigep.svg?style=flat-square
    :target: https://pypi.python.org/pypi/pysigep

.. image:: https://img.shields.io/pypi/pyversions/pysigep.svg?style=flat-square
    :target: https://pypi.python.org/pypi/pysigep

.. image:: https://img.shields.io/pypi/l/pysigep.svg?style=flat-square
    :target: https://github.com/mstuttgart/pysigep/blob/develop/LICENSE

Interface python para uso dos serviços fornecidos pelo SIGEPWeb dos Correios.

Sobre
-----

O SIGEP WEB é um sistema com o propósito de preparar e gerenciar
as postagens de Clientes dos Correios. Seus principais atributos técnicos são:
facilidade e rapidez na preparação das postagens e gestão das informações sobre os objetos postados.

Features
--------

-  Verificar *status* de um Cartão de Postagem
-  Obter dados do endereço a partir de seu respectivo CEP.
-  Verificar disponibilidade de um dado serviço.
-  Gerar etiquetas para postagem de mercadoria.

Documentação
------------

Para mais detalhes sobre a PyCEPCorreios, por gentileza, consulte a documentação oficial (também disponível em Inglẽs):

* Documentação online: https://pysigep.readthedocs.io.
* Documentação PDF: `download <https://media.readthedocs.org/pdf/pysigep/stable/pysigep.pdf>`_

Instalação
----------

A versão atual **ainda esta em fase de desenvolvimento**, sendo que os recursos
disponiveis podem ser removidos sem aviso prévio. Portanto, não é recomendável
seu uso em ambiente de produção.

.. code-block:: shell

    pip install pysigep

Aviso de *bugs*, dúvidas e sugestões
------------------------------------

Para dúvidas, sugestões e relatórios de *bugs*, por gentileza, crie uma *issue*:

- Issue Tracker: https://github.com/mstuttgart/pysigep/issues

Como contribuir
---------------

Deseja participar do desenvolvimento da PyCepCorreios? Torne-se um contribuidor do PyCEPCorreios!
visite a documentação para verificar a *guideline* de contribuição:

- Veja `aqui <https://pysigep.readthedocs.io/pt/latest/contributing.html>`_.

Contribuidores
--------------

Agradecimentos aos seguintes contribuidores pelo esforço de fazer a PyCEPCorreios
melhor:

- Lista de contribuidores: https://github.com/mstuttgart/pysigep/graphs/contributors


Créditos
--------

Copyright (C) 2016-2018 por Michell Stuttgart
